@@ -4,7 +4,7 @@ use warnings;
 use FormValidator::Lite::Constraint;
 use Any::Moose ( '::Util::TypeConstraints' => [] );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 *_get_constraint = any_moose('::Util::TypeConstraints')->can('find_type_constraint');
 
@@ -12,7 +12,15 @@ my @types = any_moose('::Util::TypeConstraints')->list_all_type_constraints();
 for my $name (@types) {
     my $constraint = _get_constraint($name);
     rule $name => sub {
-        $constraint->check($_);
+        my $value = $_;
+
+        $constraint->check($value) or do {
+            return unless $constraint->has_coercion;
+
+            $value = $constraint->coerce($value);
+
+            return $constraint->check($value);
+        }
     };
 }
 
